@@ -1,7 +1,7 @@
 jags <- function (data, inits, parameters.to.save, model.file = "model.bug", 
   n.chains = 3, n.iter = 2000, n.burnin = floor(n.iter/2), 
   n.thin = max(1, floor((n.iter - n.burnin)/n.sims)), n.sims = 1000, 
-  n.adapt = 1000, DIC = FALSE, working.directory = NULL) 
+  n.adapt = 1000, refresh = n.iter/50, DIC = FALSE, working.directory = NULL) 
 {
   
   require(rjags)
@@ -43,19 +43,21 @@ jags <- function (data, inits, parameters.to.save, model.file = "model.bug",
   
   if(is.null(inits)){
     m <- jags.model(model.file, data = data, n.chains = n.chains, 
-      n.adapt = n.adapt)
+      n.adapt = 0)
+    adapt(m, n.iter =  n.adapt, by = refresh) 
   }
   else{ 
     m <- jags.model(model.file, data = data, inits=inits, n.chains = n.chains, 
-      n.adapt = n.adapt)
+      n.adapt = 0)
+    adapt(m, n.iter =  n.adapt, by = refresh) 
   }
   
   if(n.burnin > 0){
-    update(m, n.burnin)
+    update(m, n.burnin, by=refresh)
   }
   
   samples <- coda.samples(model = m, variable.names = parameters.to.save, 
-      n.iter = (n.iter-n.burnin), thin = n.thin)
+      n.iter = (n.iter-n.burnin), thin = n.thin, by=refresh)
   
   fit <- mcmc2bugs(samples, model.file = model.file, program = "jags", 
       DIC = DIC, DICOutput = NULL, n.iter = n.iter, n.burnin = n.burnin, 
